import React, { useEffect, useMemo, useState } from 'react'
import { Select } from 'antd'
import { getMenTreeByRole } from '../../../../apis/process'

const pullStaff = ({ value, onChange, schema }) => {

  const { disabled, role, isMultiple, presetValue } = schema

  const [data, setData] = useState([])

  const valueShow = useMemo(() => {
    if (isMultiple) {
      return (value || presetValue) ? (value || presetValue).split(',') : []
    } else {
      return value || presetValue
    }
  }, [presetValue, value, isMultiple])

  const handleChange = (value) => {
    if (isMultiple) {
      onChange(value.join(','))
    } else {
      onChange(value)
    }
  }

  const onFocus = async () => {
    const { code, data, msg } = await getMenTreeByRole({ userID: 1, role })
    if (code === 0) {
      if (data && data.childNodes) {
        setData(data.childNodes)
      }
    } else {
      onChange(`请求错误,${msg}`)
    }
  }

  return (
    <Select
      style={{ minWidth: 150 }}
      mode={isMultiple ? 'multiple' : ''}
      disabled={disabled}
      value={valueShow}
      optionFilterProp="children"
      placeholder={disabled ? null : '点击选择人员'}
      onChange={handleChange}
      onFocus={onFocus}
      showSearch
      showArrow={!disabled}
    >
      {data.map(v => <Select.Option key={v.value} value={v.value}>{v.text}</Select.Option>)}
    </Select>
  )

}

export default pullStaff;
