/*
 ** 人员选择器 单选
 ** create by ChenLong on 2021/12/21
 ** 功能路径：src\core\components\staffSelect\staffSelect.js
 ** 菜单参数列表：*变量名*(变量说明，数据类型，是否必填，取值范围)
 ** 更新日志：
 ** edit by ChenLong on 2021/12/21: *****修改内容*****
 ** 形态：【人员选择器】
 ** 现阶段仅支持机构
 ** 显示名称，存储id，多个id以英文逗分隔
 **配置：全部 [.n]                   返回全部的机构及人员列表
        机构名称 [.n]               返回设定的机构及人员列表
        (机构名称,机构名称 ...) [.n] 返回设定的某几个机构人员列表
 */

import React, { useEffect, useState } from 'react';
import { Input, Modal, Radio, Spin } from 'antd';
import { UserAddOutlined } from '@ant-design/icons';
import Empty from '@wisdom-components/empty';
import { getUserListForRole } from '../../../../apis/process';
import './staffSelect.less';

const { Search } = Input;

const StaffSelect = ({ value, onChange, name, schema }) => {

  const { disabled } = schema

  const [visible, setVisible] = useState(false);
  const [defaultPerson, setDefaultPerson] = useState([]);
  const [personArr, setPersonArr] = useState([]);
  const [person, setPerson] = useState(value);
  const [searchVal, setSearchVal] = useState('');
  const [loading, setLoading] = useState(true);
  // [全部][.n]     [全部.机构名][.n]
  // [全部ID][.n]   [全部ID.机构名][.n]
  // [机构名][.n]   [(机构名,机构名,机构名)][.n]
  const ouConfig = schema.config;
  // [全部][,n]     [全部,机构名][,n]
  // [全部ID][,n]   [全部ID,机构名][,n]
  // [机构名][,n]   [(机构名,机构名,机构名)][,n]
  let ouConfigArray = schema.config.split('.');
  const isAll = ['全部', '全部ID'].includes(ouConfigArray[0]);
  const storeType = isAll && ouConfigArray[0] === '全部ID' ? 'storeID' : 'storeName';
  const isMultiple = !isAll && ouConfigArray[0].includes(',') && ouConfigArray[0].includes('(') && ouConfigArray[0].includes(')'); // (机构名,机构名)
  /**
   *  @Description: 根据配置来返回ID或者名字
   *  @Params: value当前控件传入的值；
   *  @Date: 2021/12/28
   *  @Author: ChenLong
   * */
  const returnUserName = (value) => {
    if (isNaN(Number(value))) return value;
    let _list = returnUserList(personArr);
    return _list.reduce((finalStr, current) => {
      return finalStr += Number(current.userID) === Number(value) ? current.userName : '';
    }, '');
  };

  const returnUserList = (data) => {
    return data.reduce((finalArray, current) => {
      return finalArray.concat(current.userList);
    }, []);
  };

  const getData = () => {
    getUserListForRole().then(res => {
      if (res.code === 0) {
        const arr = [];
        setLoading(false);
        res.data.forEach(item => {
          // 全部 / 非全部
          if (isAll) {
            arr.push(item);
          } else if (isMultiple) {
            // 多选
            let _ouConfigArray = ouConfigArray[0].replace(/\(|\)/g, '').split(',');
            if (_ouConfigArray.includes(item.ouName)) arr.push(item);
          } else {
            // 单选
            let _ouConfigArray = ouConfigArray[0].replace(/\(|\)/g, '');
            if (_ouConfigArray.includes(item.ouName)) arr.push(item);
          }
        });
        setDefaultPerson(arr);
        setPersonArr(arr);
      } else {
        onChange('请求错误');
      }

    });
  };
  const onFocus = () => {
    setVisible(true);
  };
  const onOk = () => {
    setVisible(false);
    setSearchVal('');
    onChange(person);
  };
  const onCancel = () => {
    setVisible(false);
    setSearchVal('');
    getData();
  };
  const onInput = e => {
    onSearch(e.target.value);
  };
  const handleChange = e => {
    setPerson(e.target.value);
  };

  const onSearch = e => {
    const arr = [];
    setSearchVal(e);
    defaultPerson.map(item => {
      const list = {
        ouid: item.ouid,
        ouName: item.ouName,
        userList: [],
      };
      item.userList.map(user => {
        if (user.userName.indexOf(e) > -1) {
          list.userList.push(user);
        }
      });
      if (list.userList.length) {
        arr.push(list);
      }
    });
    setPersonArr(arr);
  };

  useEffect(() => {
    async function _getData() {
      await getData();
    }

    _getData().catch(err => {
      console.log(err);
    });
  }, []);

  return (
    <div className="personselect-wrapper" style={{ width: '100%' }}>
      <Input
        disabled={disabled}
        placeholder={disabled ? null : '点击选择人员'}
        value={returnUserName(value) || null}
        addonAfter={disabled ? null : <UserAddOutlined style={{ color: 'rgba(0, 0, 0, 0.25)' }} onClick={onFocus} />}
        style={{ width: '100%' }}
      />
      <Modal
        title="人员选择器"
        visible={visible}
        onOk={onOk}
        onCancel={onCancel}
        cancelText={'取消'}
        okText={'确定'}
        wrapClassName="personModalClass"
        bodyStyle={{ width: '80%', height: 450, overflowY: 'auto' }}
      >
        {loading && <Spin />}
        <Search
          placeholder="请输入姓名"
          value={searchVal}
          allowClear
          onSearch={onSearch}
          onChange={onInput}
          enterButton
        />
        {!personArr.length && (
          <div className={'staffSelectEmpty'}>
            <Empty />
          </div>
        )}
        {personArr.length
          ? personArr.map((item, index) => {
            return (
              <form key={index} className="fieldset-class">
                <fieldset className="person-select">
                  <legend className="personheader">{item.ouName}</legend>
                  <Radio.Group className="person-radio" name="person" onChange={handleChange} value={person}>
                    {item.userList.map((child, childIndex) => {
                      return (
                        <Radio value={storeType === 'storeID' ? child.userID : child.userName} key={childIndex}>
                          {child.userName}
                        </Radio>
                      );
                    })}
                  </Radio.Group>
                </fieldset>
              </form>
            );
          })
          : ''}
      </Modal>
    </div>
  );
};

export default StaffSelect;
