// 搜索选择器，配置字典
/*
 ** 选择器
 ** create by ChenLong on 2021/12/15
 ** 功能路径：src\core\components\selectTree\selectTree.js
 ** 菜单参数列表：*变量名*(变量说明，数据类型，是否必填，取值范围)
 ** 更新日志：
 *  使用搜索选择器，重写选择器的里的逻辑，并且通过新增FormRender的watch属性，来实现关联选择器的联动
 ** edit by ChenLong on 2021/12/15: *****修改内容*****
 */

/**
 *  @Description: 1. 单选情况下，传值时字符窜；2. 多选情况下，传值时数组；
 *  @Date: 2021/12/15
 * */

import React, { useState, useEffect } from 'react';
import { Select } from 'antd';
import { getSelectName } from '../../../../apis/process';

const { Option } = Select;

const SelectTree = ({ value, onChange, schema }) => {

  const { disabled, placeholder } = schema
  const [selectList, setSelectList] = useState([]);
  const [mode, setMode] = useState('');
  // 判断当前时单选还是多选
  const _configArray = schema.config.split('.');
  const isMultiple = !!(_configArray[2] && _configArray[2] === 'n');

  const val = value || schema.default;

  const handleChange = value => {
    onChange(value);
  };

  const getData = () => {
    const arr = schema.config.split('.');
    if (!arr.length) return false;
    // 区别于搜索选择器
    const dictionaryName = arr[1] || arr[0];
    if (isMultiple) {
      setMode('multiple');
    } else {
      setMode('');
    }
    getSelectName(dictionaryName).then(res => {
      if (res.code === 0) {
        let _list = res.data;
        if (schema.filterKey) _list = _list.filter(item => item.nodeName === schema.filterKey);
        setSelectList(_list);
      } else {
        onChange('请求错误');
      }
    });
  };

  useEffect(() => {
    // 初始化的时候，处理单选/多选问题
    const handleInitData = Object.prototype.toString.call(val) === '[object String]' && val ? val.split(',') : val;
    let _val = isMultiple ? handleInitData : val;
    onChange(_val);
    // getData();
  }, []);

  return (
    <Select
      disabled={disabled}
      mode={mode}
      showSearch
      optionFilterProp="children"
      value={null}
      onChange={handleChange}
      onFocus={() => getData()}
      placeholder={placeholder}
      style={{ width: '100%' }}
    >
      {selectList.map((item, index) => {
        return (
          <Option value={item.nodeValue} key={index}>
            {item.nodeValue}
          </Option>
        );
      })}
    </Select>
  );
};

export default SelectTree;
